# pyDataViz
This package is created by Amir H. to help him reuse the code he has written in the past. Most of the codes are written using the already written code on the internet but modified for specific use in Transportation studies. 
## Installation
Run the following to install:
```python
pip install pyDataViz
```
## Usage
```python
from pyDataViz import histogram
histogram.prepForHistogram(data_array, num_digits = 0)
```



Follow Amir on [Twitter](https://twitter.com/PersonOnBicycle).
